/*
 * nid2ost.c
 *
 * @author: fwang2
 */

#include "fgr.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

int main(int argc, char** argv) {
    fs_t partition;

    fgr_init(".");

    if (argc != 4 ) {
        fprintf(stderr, "Usage: nid2ost [atlas1|atlas2|atlas] [nodelist] [number]\n");
        exit(1);
    }


    if (strcmp(argv[1], "atlas1") == 0)
        partition = ATLAS1;
    else if (strcmp(argv[1], "atlas2") == 0)
        partition = ATLAS2;
    else if (strcmp(argv[1], "atlas") == 0)
        partition = ATLAS;
    else {
        fprintf(stderr, "Unrecognized partition: %s\n", argv[1]);
        exit(1);
    }

    uint32_t count = atoi(argv[3]);

    /* crude error check */
    if (count > 18686) {
        fprintf(stderr, "Out of range %d\n", count);
        exit(1);
    }

    fprintf(stdout, "Selecting %d nids\n", count);

    /* allocating space */
    uint32_t * nids =  malloc( count * sizeof(uint32_t));
    uint32_t * osts =  malloc( count * sizeof(uint32_t));

    /* read in nids */
    FILE * fp = fopen(argv[2], "r");
    if ( fp == NULL) {
        fprintf(stderr, "Failed to open %s\n", argv[2]);
        exit(1);
    }

    uint32_t idx = 0;
    char buff[64];
    while (idx < count) {
        if (fgets(buff, 64, fp) == NULL) break;
        nids[idx] = atoi(buff);
        idx++;
    }

    if ( fp != NULL) {
        fclose(fp);
    }

    fgr_nid2ost(nids, osts, count, partition);
    fgr_rtr_debug();
    fgr_lnet_debug();
    fgr_oss_debug();
    fgr_ost_debug();
    fgr_finalize();

    fprintf(stdout, "Selected OSTs: ");

    for (int i = 0; i < count; i++) {
        fprintf(stdout, "%" PRIu32 " ", osts[i] );
    }
    fprintf(stdout, "\n");
    return 0;
}
